@@ -36,8 +36,6 @@ public:
   BoolParameter(QObject * parent = 0);
   ~BoolParameter();
   void addTo(QWidget *, int row) override;
-  void addToKeypointList(KeypointList &) const override;
-  void extractPositionFromKeypointList(KeypointList &) override;
   QString textValue() const override;
   void setValue(const QString & value) override;
   void reset() override;
