@@ -80,7 +80,7 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   ui->tbResetParameters->setToolTip(tr("Reset parameters to default values"));
   ui->tbResetParameters->setVisible(false);
 
-  ui->tbUpdateFilters->setToolTip(tr("Update filters"));
+  ui->tbUpdateFilters->setToolTip(tr("Update filters (Ctrl+R / F5)"));
 
   ui->tbRenameFave->setToolTip(tr("Rename fave"));
   ui->tbRenameFave->setEnabled(false);
@@ -132,6 +132,13 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   connect(searchAction, SIGNAL(triggered(bool)), ui->searchField, SLOT(setFocus()));
   addAction(searchAction);
 
+  ui->tbUpdateFilters->setShortcut(QKeySequence("Ctrl+R"));
+  QAction * updateFiltersAction = new QAction(this);
+  updateFiltersAction->setShortcut(QKeySequence("F5"));
+  updateFiltersAction->setShortcutContext(Qt::ApplicationShortcut);
+  connect(updateFiltersAction, SIGNAL(triggered(bool)), ui->tbUpdateFilters, SLOT(click()));
+  addAction(updateFiltersAction);
+
   ui->splitter->setHandleWidth(6);
   ui->verticalSplitter->setHandleWidth(6);
   ui->verticalSplitter->setStretchFactor(0, 5);
@@ -165,7 +172,6 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   TIMING;
   makeConnections();
   TIMING;
-  _keypointBurstEnabled = true;
 }
 
 MainWindow::~MainWindow()
@@ -552,13 +558,14 @@ void MainWindow::onPreviewKeypointsEvent(unsigned int flags, unsigned long time)
   if (flags & PreviewWidget::KeypointMouseReleaseEvent) {
     ui->filterParams->setKeypoints(ui->previewWidget->keypoints(), true);
     _lastPreviewKeypointBurstUpdateTime = 0;
-    _processor.resetLastSynchronousExecutionDurationMS();
   } else {
     ui->filterParams->setKeypoints(ui->previewWidget->keypoints(), false);
-    if ((flags & PreviewWidget::KeypointBurstEvent) && _keypointBurstEnabled) {
+    if ((flags & PreviewWidget::KeypointBurstEvent)) {
+      const ulong t = (ulong)_processor.lastPreviewFilterExecutionDurationMS();
+      const bool keypointBurstEnabled = (t <= KEYPOINTS_INTERACTIVE_LOWER_DELAY_MS) ||
+                                        ((t <= KEYPOINTS_INTERACTIVE_UPPER_DELAY_MS) && ((ulong)_processor.averagePreviewFilterExecutionDuration() <= KEYPOINTS_INTERACTIVE_MIDDLE_DELAY_MS));
       ulong msSinceLastBurstEvent = time - _lastPreviewKeypointBurstUpdateTime;
-      _keypointBurstEnabled = ((ulong)_processor.lastSynchronousExecutionDurationMS() <= KEYPOINTS_INTERACTIVE_DELAY_MS);
-      if (_keypointBurstEnabled && (msSinceLastBurstEvent >= (ulong)_processor.lastSynchronousExecutionDurationMS())) {
+      if (keypointBurstEnabled && (msSinceLastBurstEvent >= (ulong)_processor.lastPreviewFilterExecutionDurationMS())) {
         onPreviewUpdateRequested(true);
         _lastPreviewKeypointBurstUpdateTime = time;
       }
@@ -979,7 +986,8 @@ void MainWindow::activateFilter(bool resetZoom)
 {
   saveCurrentParameters();
   const FiltersPresenter::Filter & filter = _filtersPresenter->currentFilter();
-  _keypointBurstEnabled = true;
+  _processor.resetLastPreviewFilterExecutionDurations();
+
   if (filter.hash.isEmpty()) {
     setNoFilter();
   } else {
